package dev.shadowsoffire.apotheosis.village.wanderer;

import dev.shadowsoffire.apotheosis.adventure.affix.trades.AffixTrade;
import com.mojang.serialization.Codec;
import dev.shadowsoffire.apotheosis.Apotheosis;
import java.util.ArrayList;
import java.util.HashMap;
import dev.shadowsoffire.apotheosis.village.VillageModule;
import net.minecraft.world.entity.npc.VillagerTrades;
import java.util.List;
import net.minecraftforge.common.BasicItemListing;
import net.minecraft.resources.ResourceLocation;
import java.util.Map;
import dev.shadowsoffire.placebo.reload.DynamicRegistry;

public class WandererTradesRegistry extends DynamicRegistry<JsonTrade>
{
    public static final WandererTradesRegistry INSTANCE;
    protected final Map<ResourceLocation, BasicItemListing> registry;
    protected final List<VillagerTrades.ItemListing> normTrades;
    protected final List<VillagerTrades.ItemListing> rareTrades;
    
    public WandererTradesRegistry() {
        super(VillageModule.LOGGER, "wanderer_trades", false, true);
        this.registry = new HashMap<ResourceLocation, BasicItemListing>();
        this.normTrades = new ArrayList<VillagerTrades.ItemListing>();
        this.rareTrades = new ArrayList<VillagerTrades.ItemListing>();
    }
    
    protected void registerBuiltinCodecs() {
        this.registerDefaultCodec(Apotheosis.loc("basic_trade"), (Codec)WandererTrade.CODEC);
        this.registerCodec(Apotheosis.loc("affix"), AffixTrade.CODEC);
    }
    
    protected void beginReload() {
        super.beginReload();
        this.normTrades.clear();
        this.rareTrades.clear();
    }
    
    protected void onReload() {
        super.onReload();
        this.getValues().forEach(trade -> {
            if (trade.isRare()) {
                this.rareTrades.add((VillagerTrades.ItemListing)trade);
            }
            else {
                this.normTrades.add((VillagerTrades.ItemListing)trade);
            }
        });
    }
    
    public List<VillagerTrades.ItemListing> getNormalTrades() {
        return this.normTrades;
    }
    
    public List<VillagerTrades.ItemListing> getRareTrades() {
        return this.rareTrades;
    }
    
    static {
        INSTANCE = new WandererTradesRegistry();
    }
}
